# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/config/postgresql15_1c.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/mdb/postgresql/v1/config/postgresql15_1c.proto\x12%yandex.cloud.mdb.postgresql.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x9cn\n\x15PostgresqlConfig15_1C\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0eshared_buffers\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0ctemp_buffers\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08work_mem\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14maintenance_work_mem\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x61utovacuum_work_mem\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0ftemp_file_limit\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11vacuum_cost_delay\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14vacuum_cost_page_hit\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15vacuum_cost_page_miss\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16vacuum_cost_page_dirty\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11vacuum_cost_limit\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x41\n\x0e\x62gwriter_delay\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-10000\x12:\n\x15\x62gwriter_lru_maxpages\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x17\x62gwriter_lru_multiplier\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\x14\x62gwriter_flush_after\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t0-2097152\x12G\n\x13\x62\x61\x63kend_flush_after\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t0-2097152\x12L\n\x16old_snapshot_threshold\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b-1-86400000\x12X\n\twal_level\x18\x14 \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.WalLevel\x12j\n\x12synchronous_commit\x18\x15 \x01(\x0e\x32N.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.SynchronousCommit\x12K\n\x12\x63heckpoint_timeout\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x33\x30\x30\x30\x30-86400000\x12\x42\n\x1c\x63heckpoint_completion_target\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n\x16\x63heckpoint_flush_after\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t0-2097152\x12\x31\n\x0cmax_wal_size\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cmin_wal_size\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bmax_standby_streaming_delay\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19\x64\x65\x66\x61ult_statistics_target\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12n\n\x14\x63onstraint_exclusion\x18\x1d \x01(\x0e\x32P.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.ConstraintExclusion\x12;\n\x15\x63ursor_tuple_fraction\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n\x13\x66rom_collapse_limit\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x31-2147483647\x12J\n\x13join_collapse_limit\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x31-2147483647\x12k\n\x13\x66orce_parallel_mode\x18! \x01(\x0e\x32N.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.ForceParallelMode\x12\x62\n\x13\x63lient_min_messages\x18\" \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.LogLevel\x12_\n\x10log_min_messages\x18# \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.LogLevel\x12\x66\n\x17log_min_error_statement\x18$ \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.LogLevel\x12?\n\x1alog_min_duration_statement\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0flog_checkpoints\x18& \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0flog_connections\x18\' \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18( \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_duration\x18) \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12k\n\x13log_error_verbosity\x18* \x01(\x0e\x32N.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.LogErrorVerbosity\x12\x32\n\x0elog_lock_waits\x18+ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\rlog_statement\x18, \x01(\x0e\x32I.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.LogStatement\x12\x33\n\x0elog_temp_files\x18- \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x13\n\x0bsearch_path\x18. \x01(\t\x12\x30\n\x0crow_security\x18/ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12x\n\x1d\x64\x65\x66\x61ult_transaction_isolation\x18\x30 \x01(\x0e\x32Q.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.TransactionIsolation\x12\x36\n\x11statement_timeout\x18\x31 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0clock_timeout\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n#idle_in_transaction_session_timeout\x18\x33 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12^\n\x0c\x62ytea_output\x18\x34 \x01(\x0e\x32H.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.ByteaOutput\x12Y\n\txmlbinary\x18\x35 \x01(\x0e\x32\x46.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.XmlBinary\x12Y\n\txmloption\x18\x36 \x01(\x0e\x32\x46.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.XmlOption\x12;\n\x16gin_pending_list_limit\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10\x64\x65\x61\x64lock_timeout\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_locks_per_transaction\x18\x39 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_pred_locks_per_transaction\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0b\x61rray_nulls\x18; \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x64\n\x0f\x62\x61\x63kslash_quote\x18< \x01(\x0e\x32K.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.BackslashQuote\x12\x35\n\x11\x64\x65\x66\x61ult_with_oids\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15\x65scape_string_warning\x18> \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14lo_compat_privileges\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15quote_all_identifiers\x18\x41 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x1bstandard_conforming_strings\x18\x42 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14synchronize_seqscans\x18\x43 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15transform_null_equals\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rexit_on_error\x18\x45 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\rseq_page_cost\x18\x46 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10random_page_cost\x18G \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x45\n\x16\x61utovacuum_max_workers\x18H \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-32\x12M\n\x1c\x61utovacuum_vacuum_cost_delay\x18I \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06-1-100\x12O\n\x1c\x61utovacuum_vacuum_cost_limit\x18J \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08-1-10000\x12J\n\x12\x61utovacuum_naptime\x18K \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r1000-86400000\x12H\n\x0f\x61rchive_timeout\x18L \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x30\x30\x30-86400000\x12N\n\x19track_activity_query_size\x18M \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n100-102400\x12\x39\n\x15online_analyze_enable\x18O \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x65nable_bitmapscan\x18P \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_hashagg\x18Q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_hashjoin\x18R \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x65nable_indexscan\x18S \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65nable_indexonlyscan\x18T \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_material\x18U \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x65nable_mergejoin\x18V \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_nestloop\x18W \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_seqscan\x18X \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x65nable_sort\x18Y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_tidscan\x18Z \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n\x14max_worker_processes\x18[ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12\x45\n\x14max_parallel_workers\x18\\ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12P\n\x1fmax_parallel_workers_per_gather\x18] \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12Q\n\x1e\x61utovacuum_vacuum_scale_factor\x18^ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12R\n\x1f\x61utovacuum_analyze_scale_factor\x18_ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12\x41\n\x1d\x64\x65\x66\x61ult_transaction_read_only\x18` \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x10\n\x08timezone\x18\x61 \x01(\t\x12:\n\x16\x65nable_parallel_append\x18\x62 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65nable_parallel_hash\x18\x63 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x18\x65nable_partition_pruning\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1e\x65nable_partitionwise_aggregate\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x19\x65nable_partitionwise_join\x18\x66 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\x03jit\x18g \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n max_parallel_maintenance_workers\x18h \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x1dparallel_leader_participation\x18i \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n\x1blog_transaction_sample_rate\x18k \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12\x63\n\x0fplan_cache_mode\x18l \x01(\x0e\x32J.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.PlanCacheMode\x12I\n\x18\x65\x66\x66\x65\x63tive_io_concurrency\x18m \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1000\x12M\n\x14\x65\x66\x66\x65\x63tive_cache_size\x18n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-549755813888\x12u\n\x18shared_preload_libraries\x18o \x03(\x0e\x32S.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.SharedPreloadLibraries\x12U\n\x1d\x61uto_explain_log_min_duration\x18p \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12<\n\x18\x61uto_explain_log_analyze\x18q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x18\x61uto_explain_log_buffers\x18r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x17\x61uto_explain_log_timing\x18s \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x19\x61uto_explain_log_triggers\x18t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x18\x61uto_explain_log_verbose\x18u \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\"auto_explain_log_nested_statements\x18v \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\x18\x61uto_explain_sample_rate\x18w \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12<\n\x18pg_hint_plan_enable_hint\x18x \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1epg_hint_plan_enable_hint_table\x18y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12s\n\x18pg_hint_plan_debug_print\x18z \x01(\x0e\x32Q.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.PgHintPlanDebugPrint\x12i\n\x1apg_hint_plan_message_level\x18{ \x01(\x0e\x32\x45.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.LogLevel\x12I\n\x13hash_mem_multiplier\x18| \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\xc7\x31\n0.0-1000.0\x12W\n\x19logical_decoding_work_mem\x18~ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x17\xfa\xc7\x31\x13\x36\x35\x35\x33\x36-1099511627776\x12K\n\x1amaintenance_io_concurrency\x18\x7f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1000\x12U\n\x16max_slot_wal_keep_size\x18\x80\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x17\xfa\xc7\x31\x13-1-2251799812636672\x12L\n\rwal_keep_size\x18\x81\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x17\xfa\xc7\x31\x13-1-2251799812636672\x12<\n\x17\x65nable_incremental_sort\x18\x82\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12[\n\"autovacuum_vacuum_insert_threshold\x18\x83\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12[\n%autovacuum_vacuum_insert_scale_factor\x18\x84\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\r\xfa\xc7\x31\t0.0-100.0\x12P\n\x17log_min_duration_sample\x18\x85\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12M\n\x19log_statement_sample_rate\x18\x86\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12Q\n\x18log_parameter_max_length\x18\x87\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12Z\n!log_parameter_max_length_on_error\x18\x88\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12Y\n client_connection_check_interval\x18\x89\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12\x38\n\x13\x65nable_async_append\x18\x8a\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x12\x65nable_gathermerge\x18\x8b\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0e\x65nable_memoize\x18\x8c\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12@\n\x1blog_recovery_conflict_waits\x18\x8d\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x13vacuum_failsafe_age\x18\x8e\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12V\n\x1dvacuum_multixact_failsafe_age\x18\x8f\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12\x39\n\x14pg_qualstats_enabled\x18\x90\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1cpg_qualstats_track_constants\x18\x91\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x10pg_qualstats_max\x18\x92\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19pg_qualstats_resolve_oids\x18\x93\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x18pg_qualstats_sample_rate\x18\x94\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\x19plantuner_fix_empty_table\x18\x95\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x0fmax_stack_depth\x18\x96\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x36\x35\x35\x33\x36-134217728\x12?\n\x1a\x65nable_group_by_reordering\x18\x97\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x04geqo\x18\x98\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\x0egeqo_threshold\x18\x99\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x32-2147483647\x12;\n\x0bgeqo_effort\x18\x9a\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-10\x12\x34\n\x0egeqo_pool_size\x18\x9b\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10geqo_generations\x18\x9c\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n\x13geqo_selection_bias\x18\x9d\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x31.5-2.0\x12=\n\tgeqo_seed\x18\x9e\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12P\n\x1cpg_trgm_similarity_threshold\x18\x9f\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12U\n!pg_trgm_word_similarity_threshold\x18\xa0\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12\\\n(pg_trgm_strict_word_similarity_threshold\x18\xa1\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.0-1.0\x12?\n\x19max_standby_archive_delay\x18\xa2\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12P\n\x18session_duration_timeout\x18\xa3\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12=\n\x18log_replication_commands\x18\xa4\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n\x1blog_autovacuum_min_duration\x18\xa5\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12m\n\x13password_encryption\x18\xa7\x01 \x01(\x0e\x32O.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C.PasswordEncryption\"\x9a\x01\n\x0e\x42\x61\x63kslashQuote\x12\x1f\n\x1b\x42\x41\x43KSLASH_QUOTE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41\x43KSLASH_QUOTE\x10\x01\x12\x16\n\x12\x42\x41\x43KSLASH_QUOTE_ON\x10\x02\x12\x17\n\x13\x42\x41\x43KSLASH_QUOTE_OFF\x10\x03\x12!\n\x1d\x42\x41\x43KSLASH_QUOTE_SAFE_ENCODING\x10\x04\"[\n\x0b\x42yteaOutput\x12\x1c\n\x18\x42YTEA_OUTPUT_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42YTEA_OUTPUT_HEX\x10\x01\x12\x18\n\x14\x42YTEA_OUTPUT_ESCAPED\x10\x02\"\x9a\x01\n\x13\x43onstraintExclusion\x12$\n CONSTRAINT_EXCLUSION_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONSTRAINT_EXCLUSION_ON\x10\x01\x12\x1c\n\x18\x43ONSTRAINT_EXCLUSION_OFF\x10\x02\x12\"\n\x1e\x43ONSTRAINT_EXCLUSION_PARTITION\x10\x03\"\x92\x01\n\x11\x46orceParallelMode\x12#\n\x1f\x46ORCE_PARALLEL_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x46ORCE_PARALLEL_MODE_ON\x10\x01\x12\x1b\n\x17\x46ORCE_PARALLEL_MODE_OFF\x10\x02\x12\x1f\n\x1b\x46ORCE_PARALLEL_MODE_REGRESS\x10\x03\"\x99\x01\n\x11LogErrorVerbosity\x12#\n\x1fLOG_ERROR_VERBOSITY_UNSPECIFIED\x10\x00\x12\x1d\n\x19LOG_ERROR_VERBOSITY_TERSE\x10\x01\x12\x1f\n\x1bLOG_ERROR_VERBOSITY_DEFAULT\x10\x02\x12\x1f\n\x1bLOG_ERROR_VERBOSITY_VERBOSE\x10\x03\"\x92\x02\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\x14\n\x10LOG_LEVEL_DEBUG5\x10\x01\x12\x14\n\x10LOG_LEVEL_DEBUG4\x10\x02\x12\x14\n\x10LOG_LEVEL_DEBUG3\x10\x03\x12\x14\n\x10LOG_LEVEL_DEBUG2\x10\x04\x12\x14\n\x10LOG_LEVEL_DEBUG1\x10\x05\x12\x11\n\rLOG_LEVEL_LOG\x10\x06\x12\x14\n\x10LOG_LEVEL_NOTICE\x10\x07\x12\x15\n\x11LOG_LEVEL_WARNING\x10\x08\x12\x13\n\x0fLOG_LEVEL_ERROR\x10\t\x12\x13\n\x0fLOG_LEVEL_FATAL\x10\n\x12\x13\n\x0fLOG_LEVEL_PANIC\x10\x0b\"\x8a\x01\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x16\n\x12LOG_STATEMENT_NONE\x10\x01\x12\x15\n\x11LOG_STATEMENT_DDL\x10\x02\x12\x15\n\x11LOG_STATEMENT_MOD\x10\x03\x12\x15\n\x11LOG_STATEMENT_ALL\x10\x04\"}\n\x12PasswordEncryption\x12#\n\x1fPASSWORD_ENCRYPTION_UNSPECIFIED\x10\x00\x12\x1b\n\x17PASSWORD_ENCRYPTION_MD5\x10\x01\x12%\n!PASSWORD_ENCRYPTION_SCRAM_SHA_256\x10\x02\"\xd0\x01\n\x14PgHintPlanDebugPrint\x12(\n$PG_HINT_PLAN_DEBUG_PRINT_UNSPECIFIED\x10\x00\x12 \n\x1cPG_HINT_PLAN_DEBUG_PRINT_OFF\x10\x01\x12\x1f\n\x1bPG_HINT_PLAN_DEBUG_PRINT_ON\x10\x02\x12%\n!PG_HINT_PLAN_DEBUG_PRINT_DETAILED\x10\x03\x12$\n PG_HINT_PLAN_DEBUG_PRINT_VERBOSE\x10\x04\"\x99\x01\n\rPlanCacheMode\x12\x1f\n\x1bPLAN_CACHE_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14PLAN_CACHE_MODE_AUTO\x10\x01\x12%\n!PLAN_CACHE_MODE_FORCE_CUSTOM_PLAN\x10\x02\x12&\n\"PLAN_CACHE_MODE_FORCE_GENERIC_PLAN\x10\x03\"\xad\x03\n\x16SharedPreloadLibraries\x12(\n$SHARED_PRELOAD_LIBRARIES_UNSPECIFIED\x10\x00\x12)\n%SHARED_PRELOAD_LIBRARIES_AUTO_EXPLAIN\x10\x01\x12)\n%SHARED_PRELOAD_LIBRARIES_PG_HINT_PLAN\x10\x02\x12(\n$SHARED_PRELOAD_LIBRARIES_TIMESCALEDB\x10\x03\x12)\n%SHARED_PRELOAD_LIBRARIES_PG_QUALSTATS\x10\x04\x12$\n SHARED_PRELOAD_LIBRARIES_PG_CRON\x10\x05\x12&\n\"SHARED_PRELOAD_LIBRARIES_PGLOGICAL\x10\x06\x12\'\n#SHARED_PRELOAD_LIBRARIES_PG_PREWARM\x10\x07\x12$\n SHARED_PRELOAD_LIBRARIES_PGAUDIT\x10\x08\x12!\n\x1dSHARED_PRELOAD_LIBRARIES_ANON\x10\t\"\xd6\x01\n\x11SynchronousCommit\x12\"\n\x1eSYNCHRONOUS_COMMIT_UNSPECIFIED\x10\x00\x12\x19\n\x15SYNCHRONOUS_COMMIT_ON\x10\x01\x12\x1a\n\x16SYNCHRONOUS_COMMIT_OFF\x10\x02\x12\x1c\n\x18SYNCHRONOUS_COMMIT_LOCAL\x10\x03\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_WRITE\x10\x04\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_APPLY\x10\x05\"\xe6\x01\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12*\n&TRANSACTION_ISOLATION_READ_UNCOMMITTED\x10\x01\x12(\n$TRANSACTION_ISOLATION_READ_COMMITTED\x10\x02\x12)\n%TRANSACTION_ISOLATION_REPEATABLE_READ\x10\x03\x12&\n\"TRANSACTION_ISOLATION_SERIALIZABLE\x10\x04\"S\n\x08WalLevel\x12\x19\n\x15WAL_LEVEL_UNSPECIFIED\x10\x00\x12\x15\n\x11WAL_LEVEL_REPLICA\x10\x01\x12\x15\n\x11WAL_LEVEL_LOGICAL\x10\x02\"R\n\tXmlBinary\x12\x1a\n\x16XML_BINARY_UNSPECIFIED\x10\x00\x12\x15\n\x11XML_BINARY_BASE64\x10\x01\x12\x12\n\x0eXML_BINARY_HEX\x10\x02\"X\n\tXmlOption\x12\x1a\n\x16XML_OPTION_UNSPECIFIED\x10\x00\x12\x17\n\x13XML_OPTION_DOCUMENT\x10\x01\x12\x16\n\x12XML_OPTION_CONTENT\x10\x02J\x04\x08N\x10OJ\x04\x08j\x10kJ\x04\x08}\x10~J\x06\x08\xa6\x01\x10\xa7\x01J\x04\x08@\x10\x41\"\x9b\x02\n\x18PostgresqlConfigSet15_1C\x12V\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C\x12Q\n\x0buser_config\x18\x02 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1C\x12T\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfig15_1CB\x81\x01\n)yandex.cloud.api.mdb.postgresql.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1/config;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.config.postgresql15_1c_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.mdb.postgresql.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1/config;postgresql'
  _POSTGRESQLCONFIG15_1C.fields_by_name['bgwriter_delay']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['bgwriter_delay']._serialized_options = b'\372\3071\01010-10000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['bgwriter_flush_after']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['bgwriter_flush_after']._serialized_options = b'\372\3071\t0-2097152'
  _POSTGRESQLCONFIG15_1C.fields_by_name['backend_flush_after']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['backend_flush_after']._serialized_options = b'\372\3071\t0-2097152'
  _POSTGRESQLCONFIG15_1C.fields_by_name['old_snapshot_threshold']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['old_snapshot_threshold']._serialized_options = b'\372\3071\013-1-86400000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['checkpoint_timeout']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['checkpoint_timeout']._serialized_options = b'\372\3071\01630000-86400000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['checkpoint_flush_after']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['checkpoint_flush_after']._serialized_options = b'\372\3071\t0-2097152'
  _POSTGRESQLCONFIG15_1C.fields_by_name['from_collapse_limit']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['from_collapse_limit']._serialized_options = b'\372\3071\0141-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['join_collapse_limit']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['join_collapse_limit']._serialized_options = b'\372\3071\0141-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['idle_in_transaction_session_timeout']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_max_workers']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_max_workers']._serialized_options = b'\372\3071\0041-32'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_cost_delay']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_cost_delay']._serialized_options = b'\372\3071\006-1-100'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_cost_limit']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_cost_limit']._serialized_options = b'\372\3071\010-1-10000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_naptime']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_naptime']._serialized_options = b'\372\3071\r1000-86400000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['archive_timeout']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['archive_timeout']._serialized_options = b'\372\3071\01610000-86400000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['track_activity_query_size']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['track_activity_query_size']._serialized_options = b'\372\3071\n100-102400'
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_worker_processes']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_worker_processes']._serialized_options = b'\372\3071\0060-1024'
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_parallel_workers']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_parallel_workers']._serialized_options = b'\372\3071\0060-1024'
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_parallel_workers_per_gather']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_parallel_workers_per_gather']._serialized_options = b'\372\3071\0060-1024'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_scale_factor']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_scale_factor']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_analyze_scale_factor']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_analyze_scale_factor']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_parallel_maintenance_workers']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_parallel_maintenance_workers']._serialized_options = b'\372\3071\003>=0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_transaction_sample_rate']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_transaction_sample_rate']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['effective_io_concurrency']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['effective_io_concurrency']._serialized_options = b'\372\3071\0060-1000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['effective_cache_size']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['effective_cache_size']._serialized_options = b'\372\3071\0160-549755813888'
  _POSTGRESQLCONFIG15_1C.fields_by_name['auto_explain_log_min_duration']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['auto_explain_log_min_duration']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['auto_explain_sample_rate']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['auto_explain_sample_rate']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['hash_mem_multiplier']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['hash_mem_multiplier']._serialized_options = b'\372\3071\n0.0-1000.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['logical_decoding_work_mem']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['logical_decoding_work_mem']._serialized_options = b'\372\3071\02365536-1099511627776'
  _POSTGRESQLCONFIG15_1C.fields_by_name['maintenance_io_concurrency']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['maintenance_io_concurrency']._serialized_options = b'\372\3071\0060-1000'
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_slot_wal_keep_size']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_slot_wal_keep_size']._serialized_options = b'\372\3071\023-1-2251799812636672'
  _POSTGRESQLCONFIG15_1C.fields_by_name['wal_keep_size']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['wal_keep_size']._serialized_options = b'\372\3071\023-1-2251799812636672'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_insert_threshold']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_insert_threshold']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_insert_scale_factor']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['autovacuum_vacuum_insert_scale_factor']._serialized_options = b'\372\3071\t0.0-100.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_min_duration_sample']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_min_duration_sample']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_statement_sample_rate']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_statement_sample_rate']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_parameter_max_length']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_parameter_max_length']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_parameter_max_length_on_error']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_parameter_max_length_on_error']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['client_connection_check_interval']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['client_connection_check_interval']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['vacuum_failsafe_age']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['vacuum_failsafe_age']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['vacuum_multixact_failsafe_age']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['vacuum_multixact_failsafe_age']._serialized_options = b'\372\3071\r-1-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_stack_depth']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['max_stack_depth']._serialized_options = b'\372\3071\01765536-134217728'
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_threshold']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_threshold']._serialized_options = b'\372\3071\0142-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_effort']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_effort']._serialized_options = b'\372\3071\0041-10'
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_selection_bias']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_selection_bias']._serialized_options = b'\372\3071\0071.5-2.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_seed']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['geqo_seed']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['pg_trgm_similarity_threshold']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['pg_trgm_similarity_threshold']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['pg_trgm_word_similarity_threshold']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['pg_trgm_word_similarity_threshold']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['pg_trgm_strict_word_similarity_threshold']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['pg_trgm_strict_word_similarity_threshold']._serialized_options = b'\372\3071\0070.0-1.0'
  _POSTGRESQLCONFIG15_1C.fields_by_name['session_duration_timeout']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['session_duration_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_autovacuum_min_duration']._options = None
  _POSTGRESQLCONFIG15_1C.fields_by_name['log_autovacuum_min_duration']._serialized_options = b'\372\3071\r-1-2147483647'
  _globals['_POSTGRESQLCONFIG15_1C']._serialized_start=166
  _globals['_POSTGRESQLCONFIG15_1C']._serialized_end=14274
  _globals['_POSTGRESQLCONFIG15_1C_BACKSLASHQUOTE']._serialized_start=11480
  _globals['_POSTGRESQLCONFIG15_1C_BACKSLASHQUOTE']._serialized_end=11634
  _globals['_POSTGRESQLCONFIG15_1C_BYTEAOUTPUT']._serialized_start=11636
  _globals['_POSTGRESQLCONFIG15_1C_BYTEAOUTPUT']._serialized_end=11727
  _globals['_POSTGRESQLCONFIG15_1C_CONSTRAINTEXCLUSION']._serialized_start=11730
  _globals['_POSTGRESQLCONFIG15_1C_CONSTRAINTEXCLUSION']._serialized_end=11884
  _globals['_POSTGRESQLCONFIG15_1C_FORCEPARALLELMODE']._serialized_start=11887
  _globals['_POSTGRESQLCONFIG15_1C_FORCEPARALLELMODE']._serialized_end=12033
  _globals['_POSTGRESQLCONFIG15_1C_LOGERRORVERBOSITY']._serialized_start=12036
  _globals['_POSTGRESQLCONFIG15_1C_LOGERRORVERBOSITY']._serialized_end=12189
  _globals['_POSTGRESQLCONFIG15_1C_LOGLEVEL']._serialized_start=12192
  _globals['_POSTGRESQLCONFIG15_1C_LOGLEVEL']._serialized_end=12466
  _globals['_POSTGRESQLCONFIG15_1C_LOGSTATEMENT']._serialized_start=12469
  _globals['_POSTGRESQLCONFIG15_1C_LOGSTATEMENT']._serialized_end=12607
  _globals['_POSTGRESQLCONFIG15_1C_PASSWORDENCRYPTION']._serialized_start=12609
  _globals['_POSTGRESQLCONFIG15_1C_PASSWORDENCRYPTION']._serialized_end=12734
  _globals['_POSTGRESQLCONFIG15_1C_PGHINTPLANDEBUGPRINT']._serialized_start=12737
  _globals['_POSTGRESQLCONFIG15_1C_PGHINTPLANDEBUGPRINT']._serialized_end=12945
  _globals['_POSTGRESQLCONFIG15_1C_PLANCACHEMODE']._serialized_start=12948
  _globals['_POSTGRESQLCONFIG15_1C_PLANCACHEMODE']._serialized_end=13101
  _globals['_POSTGRESQLCONFIG15_1C_SHAREDPRELOADLIBRARIES']._serialized_start=13104
  _globals['_POSTGRESQLCONFIG15_1C_SHAREDPRELOADLIBRARIES']._serialized_end=13533
  _globals['_POSTGRESQLCONFIG15_1C_SYNCHRONOUSCOMMIT']._serialized_start=13536
  _globals['_POSTGRESQLCONFIG15_1C_SYNCHRONOUSCOMMIT']._serialized_end=13750
  _globals['_POSTGRESQLCONFIG15_1C_TRANSACTIONISOLATION']._serialized_start=13753
  _globals['_POSTGRESQLCONFIG15_1C_TRANSACTIONISOLATION']._serialized_end=13983
  _globals['_POSTGRESQLCONFIG15_1C_WALLEVEL']._serialized_start=13985
  _globals['_POSTGRESQLCONFIG15_1C_WALLEVEL']._serialized_end=14068
  _globals['_POSTGRESQLCONFIG15_1C_XMLBINARY']._serialized_start=14070
  _globals['_POSTGRESQLCONFIG15_1C_XMLBINARY']._serialized_end=14152
  _globals['_POSTGRESQLCONFIG15_1C_XMLOPTION']._serialized_start=14154
  _globals['_POSTGRESQLCONFIG15_1C_XMLOPTION']._serialized_end=14242
  _globals['_POSTGRESQLCONFIGSET15_1C']._serialized_start=14277
  _globals['_POSTGRESQLCONFIGSET15_1C']._serialized_end=14560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate_content_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDyandex/cloud/certificatemanager/v1/certificate_content_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\"m\n\x1dGetCertificateContentResponse\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x03 \x03(\t\x12\x13\n\x0bprivate_key\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"\x9c\x01\n\x1cGetCertificateContentRequest\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12P\n\x12private_key_format\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.certificatemanager.v1.PrivateKeyFormat*L\n\x10PrivateKeyFormat\x12\"\n\x1ePRIVATE_KEY_FORMAT_UNSPECIFIED\x10\x00\x12\t\n\x05PKCS1\x10\x01\x12\t\n\x05PKCS8\x10\x02\x32\xf2\x01\n\x19\x43\x65rtificateContentService\x12\xd4\x01\n\x03Get\x12@.yandex.cloud.certificatemanager.v1.GetCertificateContentRequest\x1a\x41.yandex.cloud.certificatemanager.v1.GetCertificateContentResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}:getContentB\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.certificatemanager.v1.certificate_content_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager'
  _CERTIFICATECONTENTSERVICE.methods_by_name['Get']._options = None
  _CERTIFICATECONTENTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}:getContent'
  _globals['_PRIVATEKEYFORMAT']._serialized_start=408
  _globals['_PRIVATEKEYFORMAT']._serialized_end=484
  _globals['_GETCERTIFICATECONTENTRESPONSE']._serialized_start=138
  _globals['_GETCERTIFICATECONTENTRESPONSE']._serialized_end=247
  _globals['_GETCERTIFICATECONTENTREQUEST']._serialized_start=250
  _globals['_GETCERTIFICATECONTENTREQUEST']._serialized_end=406
  _globals['_CERTIFICATECONTENTSERVICE']._serialized_start=487
  _globals['_CERTIFICATECONTENTSERVICE']._serialized_end=729
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.ai.assistants.v1.searchindex.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SearchIndexFile(google.protobuf.message.Message):
    """Represents a file that has been indexed within a search index."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SEARCH_INDEX_ID_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CHUNKING_STRATEGY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the file that was used for indexing."""
    search_index_id: builtins.str
    """ID of the search index that contains this file."""
    created_by: builtins.str
    """Identifier of the subject who created the file in the search index."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the file was created."""

    @property
    def chunking_strategy(self) -> yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        search_index_id: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        chunking_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy", "created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy", "created_at", b"created_at", "created_by", b"created_by", "id", b"id", "search_index_id", b"search_index_id"]) -> None: ...

global___SearchIndexFile = SearchIndexFile



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cic/v1/public_connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.cic.v1 import peering_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_peering__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/cic/v1/public_connection.proto\x12\x13yandex.cloud.cic.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a!yandex/cloud/cic/v1/peering.proto\"\xe5\x06\n\x10PublicConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x11\n\tregion_id\x18\x06 \x01(\t\x12\x1b\n\x13trunk_connection_id\x18\x07 \x01(\t\x12,\n\x07vlan_id\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cipv4_peering\x18\t \x01(\x0b\x32\x1c.yandex.cloud.cic.v1.Peering\x12Z\n\x1aipv4_allowed_service_types\x18\x0b \x03(\x0e\x32\x36.yandex.cloud.cic.v1.PublicConnection.CloudServiceType\x12$\n\x1cipv4_peer_announced_prefixes\x18\r \x03(\t\x12\x41\n\x06labels\x18\x12 \x03(\x0b\x32\x31.yandex.cloud.cic.v1.PublicConnection.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x02\n\x10\x43loudServiceType\x12\"\n\x1e\x43LOUD_SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x14\x43LOUD_SERVICE_YANDEX\x10\x01\x1a\x02\x08\x01\x12\x1c\n\x18\x43LOUD_SERVICE_ALL_PUBLIC\x10\x02\x12\x14\n\x10\x43LOUD_SERVICE_S3\x10\x03\x12\x14\n\x10\x43LOUD_SERVICE_ML\x10\x04\x12\x17\n\x13\x43LOUD_SERVICE_APIGW\x10\x05\x12$\n CLOUD_SERVICE_CONTAINER_REGISTRY\x10\x06\x12\x19\n\x15\x43LOUD_SERVICE_CONSOLE\x10\x07\x12\x1c\n\x18\x43LOUD_SERVICE_MONITORING\x10\x08\x12\x1c\n\x18\x43LOUD_SERVICE_YANDEX_GPT\x10\t\x12#\n\x1f\x43LOUD_SERVICES_ALL_API_ENDPOINT\x10\n\x12\x15\n\x11\x43LOUD_SERVICE_YMQ\x10\x0bJ\x04\x08\x04\x10\x05J\x04\x08\n\x10\x0bJ\x04\x08\x0c\x10\rJ\x04\x08\x0e\x10\x12\x42V\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.public_connection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _PUBLICCONNECTION_LABELSENTRY._options = None
  _PUBLICCONNECTION_LABELSENTRY._serialized_options = b'8\001'
  _PUBLICCONNECTION_CLOUDSERVICETYPE.values_by_name["CLOUD_SERVICE_YANDEX"]._options = None
  _PUBLICCONNECTION_CLOUDSERVICETYPE.values_by_name["CLOUD_SERVICE_YANDEX"]._serialized_options = b'\010\001'
  _globals['_PUBLICCONNECTION']._serialized_start=136
  _globals['_PUBLICCONNECTION']._serialized_end=1005
  _globals['_PUBLICCONNECTION_LABELSENTRY']._serialized_start=565
  _globals['_PUBLICCONNECTION_LABELSENTRY']._serialized_end=610
  _globals['_PUBLICCONNECTION_CLOUDSERVICETYPE']._serialized_start=613
  _globals['_PUBLICCONNECTION_CLOUDSERVICETYPE']._serialized_end=981
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.users.user_pb2
import yandex.cloud.ai.assistants.v1.users.user_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class UserServiceStub:
    """UserService provides operations for managing users."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.CreateUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_pb2.User,
    ]
    """Create a new user."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.GetUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_pb2.User,
    ]
    """Retrieve details of a specific user by its ID."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.UpdateUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_pb2.User,
    ]
    """Update an existing user."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserResponse,
    ]
    """Delete a user by its ID."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersRequest,
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersResponse,
    ]
    """List users in a specific folder."""

class UserServiceAsyncStub:
    """UserService provides operations for managing users."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.CreateUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_pb2.User,
    ]
    """Create a new user."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.GetUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_pb2.User,
    ]
    """Retrieve details of a specific user by its ID."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.UpdateUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_pb2.User,
    ]
    """Update an existing user."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserRequest,
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserResponse,
    ]
    """Delete a user by its ID."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersRequest,
        yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersResponse,
    ]
    """List users in a specific folder."""

class UserServiceServicer(metaclass=abc.ABCMeta):
    """UserService provides operations for managing users."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.assistants.v1.users.user_service_pb2.CreateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.users.user_pb2.User, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.users.user_pb2.User]]:
        """Create a new user."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.users.user_service_pb2.GetUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.users.user_pb2.User, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.users.user_pb2.User]]:
        """Retrieve details of a specific user by its ID."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ai.assistants.v1.users.user_service_pb2.UpdateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.users.user_pb2.User, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.users.user_pb2.User]]:
        """Update an existing user."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.users.user_service_pb2.DeleteUserResponse]]:
        """Delete a user by its ID."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.users.user_service_pb2.ListUsersResponse]]:
        """List users in a specific folder."""

def add_UserServiceServicer_to_server(servicer: UserServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GenerateSshCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    OS_LOGIN_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    cloud_id: builtins.str
    """the cloud must be attached to an organization"""
    organization_id: builtins.str
    subject_id: builtins.str
    """specify subject to generate certificate for default login"""
    os_login: builtins.str
    """specify os_login for a specific login"""
    public_key: builtins.str
    def __init__(
        self,
        *,
        cloud_id: builtins.str = ...,
        organization_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        os_login: builtins.str = ...,
        public_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "organization_id", b"organization_id", "os_login", b"os_login", "scope", b"scope", "subject", b"subject", "subject_id", b"subject_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "organization_id", b"organization_id", "os_login", b"os_login", "public_key", b"public_key", "scope", b"scope", "subject", b"subject", "subject_id", b"subject_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["scope", b"scope"]) -> typing.Literal["cloud_id", "organization_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["subject", b"subject"]) -> typing.Literal["subject_id", "os_login"] | None: ...

global___GenerateSshCertificateRequest = GenerateSshCertificateRequest

@typing.final
class GenerateSshCertificateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNED_CERTIFICATE_FIELD_NUMBER: builtins.int
    signed_certificate: builtins.str
    """as per specification https://cvsweb.openbsd.org/src/usr.bin/ssh/PROTOCOL.certkeys?annotate=HEAD"""
    def __init__(
        self,
        *,
        signed_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signed_certificate", b"signed_certificate"]) -> None: ...

global___GenerateSshCertificateResponse = GenerateSshCertificateResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/airflow/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.airflow.v1 import cluster_pb2 as yandex_dot_cloud_dot_airflow_dot_v1_dot_cluster__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/airflow/v1/cluster_service.proto\x12\x17yandex.cloud.airflow.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a%yandex/cloud/airflow/v1/cluster.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x14ListClustersResponse\x12\x32\n\x08\x63lusters\x18\x01 \x03(\x0b\x32 .yandex.cloud.airflow.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x99\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.airflow.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12<\n\x06\x63onfig\x18\x06 \x01(\x0b\x32&.yandex.cloud.airflow.v1.ClusterConfigB\x04\xe8\xc7\x31\x01\x12\x37\n\x07network\x18\x07 \x01(\x0b\x32&.yandex.cloud.airflow.v1.NetworkConfig\x12:\n\tcode_sync\x18\x08 \x01(\x0b\x32\'.yandex.cloud.airflow.v1.CodeSyncConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12$\n\x12service_account_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x37\n\x07logging\x18\x0b \x01(\x0b\x32&.yandex.cloud.airflow.v1.LoggingConfig\x12%\n\x0e\x61\x64min_password\x18\x0c \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x06\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xbc\x03\n\x17UpdateClusterConfigSpec\x12\x37\n\x07\x61irflow\x18\x02 \x01(\x0b\x32&.yandex.cloud.airflow.v1.AirflowConfig\x12;\n\twebserver\x18\x03 \x01(\x0b\x32(.yandex.cloud.airflow.v1.WebserverConfig\x12;\n\tscheduler\x18\x04 \x01(\x0b\x32(.yandex.cloud.airflow.v1.SchedulerConfig\x12;\n\ttriggerer\x18\x05 \x01(\x0b\x32(.yandex.cloud.airflow.v1.TriggererConfig\x12\x35\n\x06worker\x18\x06 \x01(\x0b\x32%.yandex.cloud.airflow.v1.WorkerConfig\x12;\n\x0c\x64\x65pendencies\x18\x07 \x01(\x0b\x32%.yandex.cloud.airflow.v1.Dependencies\x12\x37\n\x07lockbox\x18\x08 \x01(\x0b\x32&.yandex.cloud.airflow.v1.LockboxConfigJ\x04\x08\x01\x10\x02\"5\n\x17UpdateNetworkConfigSpec\x12\x1a\n\x12security_group_ids\x18\x01 \x03(\t\"\xb9\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.airflow.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x45\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.airflow.v1.UpdateClusterConfigSpec\x12:\n\tcode_sync\x18\x07 \x01(\x0b\x32\'.yandex.cloud.airflow.v1.CodeSyncConfig\x12\x46\n\x0cnetwork_spec\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.airflow.v1.UpdateNetworkConfigSpec\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12$\n\x12service_account_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x37\n\x07logging\x18\x0b \x01(\x0b\x32&.yandex.cloud.airflow.v1.LoggingConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf2\n\n\x0e\x43lusterService\x12\x86\x01\n\x03Get\x12*.yandex.cloud.airflow.v1.GetClusterRequest\x1a .yandex.cloud.airflow.v1.Cluster\"1\x82\xd3\xe4\x93\x02+\x12)/managed-airflow/v1/clusters/{cluster_id}\x12\x89\x01\n\x04List\x12,.yandex.cloud.airflow.v1.ListClustersRequest\x1a-.yandex.cloud.airflow.v1.ListClustersResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-airflow/v1/clusters\x12\xa7\x01\n\x06\x43reate\x12-.yandex.cloud.airflow.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02!\"\x1c/managed-airflow/v1/clusters:\x01*\x12\xb4\x01\n\x06Update\x12-.yandex.cloud.airflow.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.2)/managed-airflow/v1/clusters/{cluster_id}:\x01*\x12\xbf\x01\n\x06\x44\x65lete\x12-.yandex.cloud.airflow.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+*)/managed-airflow/v1/clusters/{cluster_id}\x12\xb4\x01\n\x05Start\x12,.yandex.cloud.airflow.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\"//managed-airflow/v1/clusters/{cluster_id}:start\x12\xb0\x01\n\x04Stop\x12+.yandex.cloud.airflow.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"./managed-airflow/v1/clusters/{cluster_id}:stop\x12\xbd\x01\n\x0eListOperations\x12\x35.yandex.cloud.airflow.v1.ListClusterOperationsRequest\x1a\x36.yandex.cloud.airflow.v1.ListClusterOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-airflow/v1/clusters/{cluster_id}/operationsBb\n\x1byandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.airflow.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflow'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['config']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['config']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['admin_password']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['admin_password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['service_account_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/managed-airflow/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\036\022\034/managed-airflow/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002!\"\034/managed-airflow/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002.2)/managed-airflow/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002+*)/managed-airflow/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0021\"//managed-airflow/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0020\"./managed-airflow/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0026\0224/managed-airflow/v1/clusters/{cluster_id}/operations'
  _globals['_GETCLUSTERREQUEST']._serialized_start=282
  _globals['_GETCLUSTERREQUEST']._serialized_end=335
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=338
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=482
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=484
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=583
  _globals['_CREATECLUSTERREQUEST']._serialized_start=586
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1251
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1200
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1245
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1253
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1296
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_start=1299
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_end=1743
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_start=1745
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_end=1798
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1801
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2498
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1200
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1245
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2500
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2543
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2545
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2601
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2603
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2646
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2648
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2703
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2705
  _globals['_STARTCLUSTERMETADATA']._serialized_end=2747
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2749
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2803
  _globals['_STOPCLUSTERMETADATA']._serialized_start=2805
  _globals['_STOPCLUSTERMETADATA']._serialized_end=2846
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2848
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=2974
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=2976
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3087
  _globals['_CLUSTERSERVICE']._serialized_start=3090
  _globals['_CLUSTERSERVICE']._serialized_end=4484
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.common.quantiles_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Report(google.protobuf.message.Message):
    """Aggregated test results."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HttpCodesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NetCodesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    HTTP_CODES_FIELD_NUMBER: builtins.int
    NET_CODES_FIELD_NUMBER: builtins.int
    QUANTILES_FIELD_NUMBER: builtins.int
    @property
    def http_codes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """Total count of HTTP responses, grouped by HTTP response code."""

    @property
    def net_codes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """Total count of network responses, grouped by response code."""

    @property
    def quantiles(self) -> yandex.cloud.loadtesting.api.v1.common.quantiles_pb2.Quantiles:
        """Response time statistics, aggregated by quantiles."""

    def __init__(
        self,
        *,
        http_codes: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
        net_codes: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
        quantiles: yandex.cloud.loadtesting.api.v1.common.quantiles_pb2.Quantiles | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["quantiles", b"quantiles"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["http_codes", b"http_codes", "net_codes", b"net_codes", "quantiles", b"quantiles"]) -> None: ...

global___Report = Report



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateAsymmetricEncryptionKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENCRYPTION_ALGORITHM_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a asymmetric KMS key in."""
    name: builtins.str
    """Name of the key."""
    description: builtins.str
    """Description of the key."""
    encryption_algorithm: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionAlgorithm.ValueType
    """Asymmetric encryption algorithm."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the symmetric KMS key"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the asymmetric KMS key as `key:value` pairs. Maximum 64 per key.
        For example, `"project": "mvp"` or `"source": "dictionary"`.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        encryption_algorithm: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionAlgorithm.ValueType = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "encryption_algorithm", b"encryption_algorithm", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateAsymmetricEncryptionKeyRequest = CreateAsymmetricEncryptionKeyRequest

@typing.final
class CreateAsymmetricEncryptionKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being created."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___CreateAsymmetricEncryptionKeyMetadata = CreateAsymmetricEncryptionKeyMetadata

@typing.final
class GetAsymmetricEncryptionKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to return.
    To get the ID of an asymmetric KMS key use a [AsymmetricEncryptionKeyService.List] request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___GetAsymmetricEncryptionKeyRequest = GetAsymmetricEncryptionKeyRequest

@typing.final
class ListAsymmetricEncryptionKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list asymmetric KMS keys in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListAsymmetricEncryptionKeysResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListAsymmetricEncryptionKeysResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAsymmetricEncryptionKeysRequest = ListAsymmetricEncryptionKeysRequest

@typing.final
class ListAsymmetricEncryptionKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListAsymmetricEncryptionKeysRequest.page_size], use
    the [next_page_token] as the value for the [ListAsymmetricEncryptionKeysRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey]:
        """List of asymmetric KMS keys in the specified folder."""

    def __init__(
        self,
        *,
        keys: collections.abc.Iterable[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keys", b"keys", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAsymmetricEncryptionKeysResponse = ListAsymmetricEncryptionKeysResponse

@typing.final
class UpdateAsymmetricEncryptionKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    KEY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to update.
    To get the ID of a asymmetric KMS key use a [AsymmetricEncryptionKeyService.List] request.
    """
    name: builtins.str
    """New name for the asymmetric KMS key."""
    description: builtins.str
    """New description for the asymmetric KMS key."""
    status: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey.Status.ValueType
    """New status for the asymmetric KMS key.
    Using the [AsymmetricEncryptionKeyService.Update] method you can only set ACTIVE or INACTIVE status.
    """
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the asymmetric KMS key"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the asymmetric KMS key are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the asymmetric KMS key as `key:value` pairs. Maximum 64 per key."""

    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey.Status.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "key_id", b"key_id", "labels", b"labels", "name", b"name", "status", b"status", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAsymmetricEncryptionKeyRequest = UpdateAsymmetricEncryptionKeyRequest

@typing.final
class UpdateAsymmetricEncryptionKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being updated."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___UpdateAsymmetricEncryptionKeyMetadata = UpdateAsymmetricEncryptionKeyMetadata

@typing.final
class DeleteAsymmetricEncryptionKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to be deleted."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___DeleteAsymmetricEncryptionKeyRequest = DeleteAsymmetricEncryptionKeyRequest

@typing.final
class DeleteAsymmetricEncryptionKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being deleted."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___DeleteAsymmetricEncryptionKeyMetadata = DeleteAsymmetricEncryptionKeyMetadata

@typing.final
class ListAsymmetricEncryptionKeyOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to get operations for.

    To get the key ID, use a [AsymmetricKeyEncryptionService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListAsymmetricEncryptionKeyOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListAsymmetricKeyOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAsymmetricEncryptionKeyOperationsRequest = ListAsymmetricEncryptionKeyOperationsRequest

@typing.final
class ListAsymmetricEncryptionKeyOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListAsymmetricEncryptionKeyOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListAsymmetricEncryptionKeyOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified key."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListAsymmetricEncryptionKeyOperationsResponse = ListAsymmetricEncryptionKeyOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.cdn.v1.raw_logs_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActivateRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource to switch logs storage for.."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "settings", b"settings"]) -> None: ...

global___ActivateRawLogsRequest = ActivateRawLogsRequest

@typing.final
class ActivateRawLogsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of resource with activated raw logs."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___ActivateRawLogsMetadata = ActivateRawLogsMetadata

@typing.final
class ActivateRawLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType
    """Raw logs status."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["settings", b"settings", "status", b"status"]) -> None: ...

global___ActivateRawLogsResponse = ActivateRawLogsResponse

@typing.final
class DeactivateRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource to deactivate Raw Logs for."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeactivateRawLogsRequest = DeactivateRawLogsRequest

@typing.final
class DeactivateRawLogsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeactivateRawLogsMetadata = DeactivateRawLogsMetadata

@typing.final
class GetRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource to request status and settings."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___GetRawLogsRequest = GetRawLogsRequest

@typing.final
class GetRawLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType
    """Raw logs status."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["settings", b"settings", "status", b"status"]) -> None: ...

global___GetRawLogsResponse = GetRawLogsResponse

@typing.final
class UpdateRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "settings", b"settings"]) -> None: ...

global___UpdateRawLogsRequest = UpdateRawLogsRequest

@typing.final
class UpdateRawLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType
    """Raw logs status."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["settings", b"settings", "status", b"status"]) -> None: ...

global___UpdateRawLogsResponse = UpdateRawLogsResponse

@typing.final
class UpdateRawLogsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___UpdateRawLogsMetadata = UpdateRawLogsMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.api_key_pb2
import yandex.cloud.iam.v1.api_key_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ApiKeyServiceStub:
    """A set of methods for managing API keys."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysResponse,
    ]
    """Retrieves the list of API keys for the specified service account."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.GetApiKeyRequest,
        yandex.cloud.iam.v1.api_key_pb2.ApiKey,
    ]
    """Returns the specified API key.

    To get the list of available API keys, make a [List] request.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyResponse,
    ]
    """Creates an API key for the specified service account."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.UpdateApiKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified API key."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.DeleteApiKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified API key."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsResponse,
    ]
    """Retrieves the list of operations for the specified API key."""

    ListScopes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesResponse,
    ]
    """Retrieves the list of scopes."""

class ApiKeyServiceAsyncStub:
    """A set of methods for managing API keys."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysResponse,
    ]
    """Retrieves the list of API keys for the specified service account."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.GetApiKeyRequest,
        yandex.cloud.iam.v1.api_key_pb2.ApiKey,
    ]
    """Returns the specified API key.

    To get the list of available API keys, make a [List] request.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyResponse,
    ]
    """Creates an API key for the specified service account."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.UpdateApiKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified API key."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.DeleteApiKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified API key."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsResponse,
    ]
    """Retrieves the list of operations for the specified API key."""

    ListScopes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesRequest,
        yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesResponse,
    ]
    """Retrieves the list of scopes."""

class ApiKeyServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing API keys."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeysResponse]]:
        """Retrieves the list of API keys for the specified service account."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.GetApiKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.api_key_pb2.ApiKey, collections.abc.Awaitable[yandex.cloud.iam.v1.api_key_pb2.ApiKey]]:
        """Returns the specified API key.

        To get the list of available API keys, make a [List] request.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.api_key_service_pb2.CreateApiKeyResponse]]:
        """Creates an API key for the specified service account."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.UpdateApiKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified API key."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.DeleteApiKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified API key."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyOperationsResponse]]:
        """Retrieves the list of operations for the specified API key."""

    @abc.abstractmethod
    def ListScopes(
        self,
        request: yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.api_key_service_pb2.ListApiKeyScopesResponse]]:
        """Retrieves the list of scopes."""

def add_ApiKeyServiceServicer_to_server(servicer: ApiKeyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.serverless.apigateway.websocket.v1 import connection_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2
from yandex.cloud.serverless.apigateway.websocket.v1 import connection_service_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2


class ConnectionServiceStub(object):
    """A set of methods for managing API Gateway WebSocket connections.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService/Get',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.GetConnectionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2.Connection.FromString,
                )
        self.Send = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService/Send',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.SendToConnectionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.SendToConnectionResponse.FromString,
                )
        self.Disconnect = channel.unary_unary(
                '/yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService/Disconnect',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.DisconnectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.DisconnectResponse.FromString,
                )


class ConnectionServiceServicer(object):
    """A set of methods for managing API Gateway WebSocket connections.
    """

    def Get(self, request, context):
        """Returns the specified connection info.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Send(self, request, context):
        """Sends data to the specified connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Disconnect(self, request, context):
        """Disconnects the specified connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.GetConnectionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2.Connection.SerializeToString,
            ),
            'Send': grpc.unary_unary_rpc_method_handler(
                    servicer.Send,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.SendToConnectionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.SendToConnectionResponse.SerializeToString,
            ),
            'Disconnect': grpc.unary_unary_rpc_method_handler(
                    servicer.Disconnect,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.DisconnectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.DisconnectResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectionService(object):
    """A set of methods for managing API Gateway WebSocket connections.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService/Get',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.GetConnectionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2.Connection.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Send(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService/Send',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.SendToConnectionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.SendToConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Disconnect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService/Disconnect',
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.DisconnectRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__service__pb2.DisconnectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """A MongoDB User resource. For more information, see the 
    [Developer's Guide](/docs/managed-mongodb/concepts).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the MongoDB user."""
    cluster_id: builtins.str
    """ID of the MongoDB cluster the user belongs to."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "permissions", b"permissions"]) -> None: ...

global___User = User

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    """Name of the database that the permission grants access to."""
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """MongoDB roles for the [database_name] database that the permission grants."""

    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_name", b"database_name", "roles", b"roles"]) -> None: ...

global___Permission = Permission

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the MongoDB user."""
    password: builtins.str
    """Password of the MongoDB user."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions to grant to the user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "password", b"password", "permissions", b"permissions"]) -> None: ...

global___UserSpec = UserSpec
